<?php
/**
 * Plugin Name: CarDealerPress
 * Plugin URI:
 * Author: DealerTrend
 * Author URI: https://www.dealertrend.com
 * Description: Provides access to the Vehicle Management System provided by <a href="https://www.dealertrend.com" target="_blank" title="DealerTrend, Inc: Shift Everything">DealerTrend, Inc.</a>
 * Version: 6.1.2301.00
 * License: GPLv2 or later
 */

require_once( dirname( __FILE__ ) . '/plugin.php' );
require_once( dirname( __FILE__ ) . '/application/helpers/check_requirements.php' );

$helper = new CDP_Requirements();
if( $helper->has_been_checked() === false ) {
	$helper->set_master_file( __FILE__ );
	if( $helper->check_requirements() === false ) {
		return false;
	}
}

$CDP = new Wordpress\Plugins\CarDealerPress\Inventory\Api\cdp_plugin();
register_deactivation_hook( __FILE__, array('cdp_clean_up', 'cdp_deactivate'));
register_uninstall_hook(__FILE__, array('cdp_clean_up', 'cdp_uninstall'));
# https://wordpress.stackexchange.com/questions/25910/uninstall-activate-deactivate-a-plugin-typical-features-how-to/25979#25979
class cdp_clean_up {

	public static function cdp_deactivate(){
		$blog_id = get_current_blog_id();
	  self::remove_cron_schedule();
		error_log("CDP Plugin has been deactived, on site id: $blog_id");
	}

# https://wordpress.stackexchange.com/questions/220854/delete-options-from-all-blogs-on-plugin-uninstall-from-a-network-multisite
	public static function cdp_uninstall(){
		if(function_exists('get_sites')) {
			$blog_ids = get_sites( array( 'fields' => 'ids' ) );
		} else {
			$blog_ids = array(get_current_blog_id());
		}
		foreach ($blog_ids as $blog_id){
			is_multisite()? switch_to_blog( $blog_id ):'';
			delete_option('cardealerpress_settings' );
			self::delete_options_prefixed( 'cdp_' );
			delete_site_transient('dt_geo_data');
			delete_site_transient('cdp_dealer_names');
			delete_transient('cdp_company_processing_'.$blog_id);
			delete_transient('cdp_company_auto_update_handler_processing_'.$blog_id);
			self::remove_inventory_tables();
			self::remove_cron_schedule();
			error_log("CDP Plugin has been uninstalled, on site id: $blog_id");
		}
	}

	public static function delete_options_prefixed( $prefix ) {
		global $wpdb;
		$wpdb->query("DELETE FROM {$wpdb->options} WHERE option_name LIKE '{$prefix}%'");
	}

	public static function remove_inventory_tables(){
		global $wpdb;
		$blog = get_current_blog_id();
		$wpdb->query('DROP TABLE cdp_inventory_import_'.$blog.'');
		$wpdb->query('DROP TABLE cdp_inventory_'.$blog.'');
		$wpdb->query('DROP TABLE cdp_data');
		$wpdb->query('DROP TABLE cdp_companies');
	}

	public static function remove_cron_schedule(){
		error_log('CDP WP Cron cdp_cron_inventory_update removed');
		$timestamp = wp_next_scheduled('cdp_cron_inventory_update');
		wp_unschedule_event($timestamp, 'cdp_cron_inventory_update');
	}
}
